@@ -59,7 +59,7 @@ class DingDingPlugin(NotificationPlugin):
             "http://web-middle.ruibogyl.work/sentry/findIssueTargetUrl",
             {"id": issue_id},
             headers={}
-        )
+        ).json()
         print issue_data
         response = requests.get(
             "http://web-middle.ruibogyl.work/sentry/getDingDingAssignee",
@@ -80,7 +80,7 @@ class DingDingPlugin(NotificationPlugin):
             },
             "at": {
                 "atMobiles": [
-                    response["phone"]
+                    response["data"]["phone"]
                 ],
                 "isAtAll": False
             }
